@@ -235,7 +235,10 @@ public:
 
 		// speex codecs
 		speexVoice,	// narrow band
-		speexAudio
+		speexAudio,
+
+		g729Audio,
+		ilbcAudio
 	};
 	typedef enum Encoding Encoding;
 
