@@ -96,6 +96,8 @@ bool AudioFile::afOpen(const char *name, Mode m)
 	case modeReadOne:
 		SETFD(file, CreateFile(name,GENERIC_READ, 0,
                         NULL, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, NULL));
+	default:
+		break;
 	}
 #else
 	switch(m)
@@ -111,6 +113,8 @@ bool AudioFile::afOpen(const char *name, Mode m)
 	case modeReadAny:
 	case modeReadOne:
 		file.fd = ::open(name, O_RDONLY);
+	default:
+		break;
 	}
 #endif
 	return isOpen();
