@@ -181,6 +181,10 @@ const char *Audio::getExtension(Encoding encoding)
 		return ".sx";
 	case g721ADPCM:
 		return ".adpcm";
+	case g729Audio:
+		return ".g729";
+	case ilbcAudio:
+		return ".ilbc";
 	default:
 		return ".au";
 	}
@@ -245,6 +249,14 @@ Audio::Encoding Audio::getEncoding(const char *name)
 		return pcm32Mono;
 	else if(!stricmp(name, "adpcm"))
 		return g721ADPCM;
+	else if(!stricmp(name, "g721"))
+		return g721ADPCM;
+	else if(!stricmp(name, "g726_32"))
+		return g721ADPCM;
+	else if(!stricmp(name, "g729"))
+		return g729Audio;
+	else if(!stricmp(name, "ilbc"))
+		return ilbcAudio;
 	else if(!stricmp(name, "mp1"))
 		return mp1Audio;
 	else if(!stricmp(name, "mp2"))
@@ -277,6 +289,12 @@ Audio::Encoding Audio::getEncoding(const char *name)
 		return voxADPCM;
 	else if(!stricmp(name, ".adpcm"))
 		return g721ADPCM;
+	else if(!stricmp(name, ".g721"))
+		return g721ADPCM;
+	else if(!stricmp(name, ".g729"))
+		return g729Audio;
+	else if(!stricmp(name, ".ilbc"))
+		return ilbcAudio;
 	else if(!stricmp(name, ".a24"))
 		return g723_3bit;
 	else if(!stricmp(name, ".a40"))
@@ -331,6 +349,10 @@ const char *Audio::getMIME(Info &info)
 		return "audio/x-vox";
 	case gsmVoice:
 		return "audio/x-gsm";
+	case g729Audio:
+		return "audio/g729";
+	case ilbcAudio:
+		return "audio/iLBC";
 	default:
 		return NULL;
 	}
@@ -357,6 +379,10 @@ const char *Audio::getName(Encoding encoding)
 		return "pcma";
 	case g721ADPCM:
 		return "adpcm";
+	case ilbcAudio:
+		return "ilbc";
+	case g729Audio:
+		return "g.729";
 	case g722Audio:
 	case g722_7bit:
 	case g722_6bit:
@@ -882,10 +908,14 @@ Audio::timeout_t Audio::getFraming(Encoding encoding, timeout_t timeout)
 	case msgsmVoice:
 		fa = 40;
 		break;
+	case g729Audio:
+		fa = 10;
+		break;
 	case gsmVoice:
 	case speexVoice:
 	case speexAudio:
-		fa = 20;
+	case ilbcAudio:
+		fa = 30;
 		break;
 	case sx96Voice:
 	case sx73Voice:
@@ -916,6 +946,10 @@ int Audio::getCount(Encoding encoding)
 		return 320;
 	case gsmVoice:
 		return 160;
+	case ilbcAudio:
+		return 240;
+	case g729Audio:
+		return 80;
 	case sx73Voice:
 	case sx96Voice:
 		return 120;
@@ -962,6 +996,12 @@ int Audio::getFrame(Encoding encoding, int samples)
 	case gsmVoice:
 		framing = 33;
 		break;
+	case ilbcAudio:
+		framing = 50;
+		break;
+	case g729Audio:
+		framing = 10;
+		break;
 	case g723_2bit:
 		framing = 1;
 		break;
